OptimizerGPU class abstract

Implementers

Constructors

OptimizerGPU(List<GPUTensor> parameters)

Properties

hashCode int
The hash code for this object.
no setterinherited
parameters List<GPUTensor>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
step(CommandBuffer tape) → void
toString() String
A string representation of this object.
inherited
zeroGrad(CommandBuffer tape) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited