activationFunctions/elu library

Classes

ELU
An activation function that applies the Exponential Linear Unit (ELU) to a Vector.
ELUMatrix
An activation function that applies the Exponential Linear Unit (ELU) to a Matrix.

Functions

matrixELU(Tensor<Matrix> m, {double alpha = 1.0}) Tensor<Matrix>
Mathematical operation for the ELU function on a matrix.
vectorELU(Tensor<Vector> v, {double alpha = 1.0}) Tensor<Vector>
Mathematical operation for the ELU function on a vector.