ELUMatrix class
An activation function that applies the Exponential Linear Unit (ELU) to a Matrix.
This version is designed to work on 2D Matrix inputs, applying the ELU
function to each element independently.
- Implemented types
Properties
Methods
-
call(
Tensor input) → Tensor< Matrix> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited