ReLUMatrix class

An activation function that applies the Rectified Linear Unit (ReLU) to a Matrix.

This version is designed to work on 2D Matrix inputs, applying the ReLU function to each element independently. It's used after layers that process batches of data, like DenseLayerMatrix.

Implemented types

Constructors

ReLUMatrix()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(Tensor input) Tensor<Matrix>
Applies the ReLU function element-wise to the input tensor.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited