SigmoidMatrix class

An activation function that applies the Sigmoid function to a Matrix.

This version is designed to work on 2D Matrix inputs, applying the Sigmoid function to each element independently.

Implemented types

Constructors

SigmoidMatrix()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(Tensor input) Tensor<Matrix>
Applies the Sigmoid function element-wise to the input tensor.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited