activationFunctions/softmax library

Classes

Softmax
An activation function that applies Softmax to a Vector.
SoftmaxMatrix
An activation function that applies Softmax to each row of a Matrix.

Functions

softmax(Tensor<Vector> v) Tensor<Vector>
Mathematical operation for the Softmax function on a vector.
softmaxMatrix(Tensor<Matrix> m) Tensor<Matrix>
Mathematical operation for applying Softmax to each row of a matrix.