SoftmaxMatrix class

An activation function that applies Softmax to each row of a Matrix.

This version is designed to work on 2D Matrix inputs, where each row is a separate set of logits for a sample in a batch.

Implemented types

Constructors

SoftmaxMatrix()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(Tensor input) Tensor<Matrix>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited