Node class

Constructors

Node(List<Tensor> inputs, Function backwardFn, {String opName = 'op', int cost = 0, Map<String, dynamic> extraParams = const {}})

Properties

backwardFn Function
final
cost int
final
extraParams Map<String, dynamic>
final
hashCode int
The hash code for this object.
no setterinherited
inputs List<Tensor>
final
opName String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited