Tensor<T> class

Constructors

Tensor(T value, {Node? creator2})

Properties

creator Node?
getter/setter pair
grad ↔ T
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value ↔ T
getter/setter pair

Methods

backward() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printGraph() → void
Prints a color-coded, visual representation of the computational graph, including computational cost and parallelizable dependency levels.
printParallelGraph() → void
toString() String
A string representation of this object.
inherited
zeroGrad() → void

Operators

operator ==(Object other) bool
The equality operator.
inherited