cpu_version/cpu_version library

Holds all the subexports of the cpu_version library.

Classes

ActivationFunction<T>
The abstract base class (or interface) for all activation functions.
Adagrad
Adam
AdamW
AMSGrad
AveragePooling2DLayer
BatchNorm1D
BatchNorm2D
Conv2DLayer
ConvLSTMLayer
DenseLayer
DenseLayerMatrix
DropoutLayer
DropoutLayerMatrix
DualLSTMLayer
A Multi-Timeline Long Short-Term Memory (MT-LSTM) layer.
ELUMatrix
An activation function that applies the Exponential Linear Unit (ELU) to a Matrix.
ELUVector
An activation function that applies the Exponential Linear Unit (ELU) to a Vector.
EmbeddingLayer
EmbeddingLayerMatrix
FlattenLayer
GlobalAveragePooling1D
GlobalAveragePoolingLayer
Layer<I, O>
LayerNormalization
LeakyReLUMatrix
LeakyReLUVector
The Leaky Rectified Linear Unit (Leaky ReLU) activation function.
LSTMLayer
MaxPooling1DLayer
MaxPooling2DLayer
MishMatrix
Mathematical operation for the Mish function on a vector.
MishVector
The Mish activation function.
Momentum
MultiHeadAttention
MultiTierLSTMLayer
NAG
Optimizer
The abstract base class for all optimization algorithms.
PositionalEncoding
ReLU
An activation function that applies the Rectified Linear Unit (ReLU) to a Vector.
ReLULayer
ReLULayerMatrix
ReLUMatrix
An activation function that applies the Rectified Linear Unit (ReLU) to a Matrix.
RMSprop
RNN
SGD
Implements the Stochastic Gradient Descent (SGD) optimizer.
Sigmoid
The Sigmoid activation function.
SigmoidMatrix
An activation function that applies the Sigmoid function to a Matrix.
SingleHeadAttention
SNetwork
A sequential model that stacks layers linearly.
SoftmaxMatrix
An activation function that applies Softmax to each row of a Matrix.
SoftmaxVector
An activation function that applies Softmax to a Vector.
SwishMatrix
The Sigmoid-weighted Linear Unit (SiLU) activation function for Matrices.
SwishVector
The Sigmoid-weighted Linear Unit (SiLU) activation function for Vectors.
TransformerEncoderBlock

Functions

flatMse(Tensor pred, Tensor target) Tensor<Scalar>
main() Future<void>