cpu_version/activationFuncitons/activationFunction library

Export the activation funcitons of this engine

Classes

ActivationFunction<T>
The abstract base class (or interface) for all activation functions.
ELUMatrix
An activation function that applies the Exponential Linear Unit (ELU) to a Matrix.
ELUVector
An activation function that applies the Exponential Linear Unit (ELU) to a Vector.
LeakyReLUMatrix
LeakyReLUVector
The Leaky Rectified Linear Unit (Leaky ReLU) activation function.
MishMatrix
Mathematical operation for the Mish function on a vector.
MishVector
The Mish activation function.
ReLU
An activation function that applies the Rectified Linear Unit (ReLU) to a Vector.
ReLUMatrix
An activation function that applies the Rectified Linear Unit (ReLU) to a Matrix.
Sigmoid
The Sigmoid activation function.
SigmoidMatrix
An activation function that applies the Sigmoid function to a Matrix.
SoftmaxMatrix
An activation function that applies Softmax to each row of a Matrix.
SoftmaxVector
An activation function that applies Softmax to a Vector.
SwishMatrix
The Sigmoid-weighted Linear Unit (SiLU) activation function for Matrices.
SwishVector
The Sigmoid-weighted Linear Unit (SiLU) activation function for Vectors.