MishVector class
The Mish activation function.
Mish is a modern, self-gated, and smooth non-monotonic activation function
that has achieved state-of-the-art results on a number of computer vision
and NLP benchmarks, often outperforming ReLU and Swish.
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
Tensor< Vector> input) → Tensor<Vector> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited