SwishVector class

The Sigmoid-weighted Linear Unit (SiLU) activation function for Vectors.

Implemented types

Constructors

SwishVector()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(Tensor<Vector> input) Tensor<Vector>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited