SNetwork class

A sequential model that stacks layers linearly.

SNetwork provides a high-level API for building, training, and evaluating neural networks, similar to Keras's Sequential model. It manages the network's layers, parameters, and the entire training lifecycle.

Inheritance

Constructors

SNetwork(List<Layer> layers, {String name = 'snetwork'})

Properties

hashCode int
The hash code for this object.
no setterinherited
layers List<Layer>
getter/setter pair
name String
getter/setter pairoverride-getter
optimizer Optimizer
getter/setter pair
parameters List<Tensor>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(Tensor input) → void
inherited
call(Tensor input) Tensor
inherited
compile({required Optimizer configuredOptimizer}) → void
evaluate(List<List<double>> inputs, List<List<double>> targets) → void
fit(List<List<double>> inputs, List<List<double>> targets, {int epochs = 100, bool averageWeight = false, bool debug = true}) → void
forward(Tensor input) Tensor
override
getWeights() Map<String, dynamic>
override
inspectGraph(List<double> inputData, List<double> targetData) → void
load(String filePath) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
predict(Tensor input) Tensor
save(String filePath) Future<void>
setWeights(Map<String, dynamic> networkWeights) → void
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited