AdamW class
Constructors
Properties
- beta1 ↔ double
-
getter/setter pair
- beta2 ↔ double
-
getter/setter pair
- epsilon ↔ double
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- learningRate ↔ double
-
getter/setter pairinherited
-
parameters
↔ List<
Tensor> -
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- weightDecay ↔ double
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
step(
) → void -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
zeroGrad(
) → void -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited