Optimizer class abstract

The abstract base class for all optimization algorithms.

Implementers

Constructors

Optimizer(List<Tensor> parameters, {required double learningRate})

Properties

hashCode int
The hash code for this object.
no setterinherited
learningRate double
getter/setter pair
parameters List<Tensor>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
step() → void
toString() String
A string representation of this object.
inherited
zeroGrad() → void

Operators

operator ==(Object other) bool
The equality operator.
inherited