SGD class

Implements the Stochastic Gradient Descent (SGD) optimizer.

Inheritance

Constructors

SGD(List<Tensor> parameters, {required double learningRate})

Properties

hashCode int
The hash code for this object.
no setterinherited
learningRate double
getter/setter pairinherited
parameters List<Tensor>
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
step() → void
override
toString() String
A string representation of this object.
inherited
zeroGrad() → void
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited