Logger class

Constructors

Logger()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

blue(String message, {String prefix = 'ℹ️'}) → void
Convenience methods for each color:
cyan(String message, {String prefix = 'ℹ️'}) → void
green(String message, {String prefix = 'ℹ️'}) → void
log(String message, {String prefix = 'ℹ️', String color = _cyan}) → void
Generic logger. You can always call Logger.log(...) if you need a custom color.
red(String message, {String prefix = 'ℹ️'}) → void
yellow(String message, {String prefix = 'ℹ️'}) → void