SilverForecaster class

Constructors

SilverForecaster({required String inputCsvPath, required String outputCsvPath, int sequenceLength = 60, int hiddenSize = 26, List<int> grainingSizes = const [7, 4], double dropoutRate = 0.25, int numModels = 4, int epochs = 8, double learningRate = 0.001})

Properties

dropoutRate double
final
epochs int
final
grainingSizes List<int>
final
hashCode int
The hash code for this object.
no setterinherited
hiddenSize int
final
inputCsvPath String
final
learningRate double
final
numModels int
final
outputCsvPath String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sequenceLength int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run() → void
The main public method to run the entire forecasting process.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited