SNetworkGPU class

Constructors

SNetworkGPU()

Properties

allParams List<GPUTensor>
getter/setter pair
bTape Uint8List
getter/setter pair
fTape Uint8List
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
inputRef GPUTensor<Matrix>
getter/setter pair
intermediates List<GPUTensor>
getter/setter pair
layers List<TapeLayer>
getter/setter pair
lossRef GPUTensor<Scalar>
getter/setter pair
optimizer OptimizerGPU
getter/setter pair
oTape Uint8List
getter/setter pair
outputRef GPUTensor
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetRef GPUTensor<Matrix>
getter/setter pair
zTape Uint8List
getter/setter pair

Methods

add(TapeLayer layer) → void
backward() → void
compile(List<int> inputShape, List<int> targetShape, double learningRate) → void
forward() GPUTensor
free() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
optimize() → void
predict(List<double> x) List
toString() String
A string representation of this object.
inherited
trainStep(List<double> x, List<double> y) double
zeroGrad() → void

Operators

operator ==(Object other) bool
The equality operator.
inherited