CommandBuffer class

Constructors

CommandBuffer()

Properties

hashCode int
The hash code for this object.
no setterinherited
offset int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

bytes() Uint8List
clear() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putBool(bool value) → void
putFloat(double value) → void
putInt(int value) → void
putString(String text) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited