CudaEngine class

Constructors

CudaEngine()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

handle int
getter/setter pair

Static Methods

addPointers(Pointer<Float> dest, Pointer<Float> src, int length) → void
dispose() → void
free(String name) → void
getTensorNames() List<String>
initialize({bool debug = false}) Future<void>
initRandomUniform(String name, double scale, int seed) → void
load(String name, Pointer<Float> data, List<int> shape) → void
retrieve(String name, Pointer<Float> destination) → void
run(Uint8List tapeBytes) → void