build method

  1. @override
void build(
  1. Tensor input
)
override

Initializes the layer's parameters based on the shape of the first input.

Subclasses should override this method to create their weights and biases. This method is called automatically by call and should not be called directly.

Implementation

@override
// No build needed as it is purely a mathematical operation.
void build(Tensor<dynamic> input) {
  super.build(input);
}