DropoutLayerMatrix class

A Dropout layer for regularizing 2D Matrix data.

During training, it randomly sets a fraction of input units to 0 with a frequency of rate. This is applied to each element of the matrix independently. This layer should only be active during training.

Inheritance

Constructors

DropoutLayerMatrix(double rate)

Properties

hashCode int
The hash code for this object.
no setterinherited
isTraining bool
getter/setter pair
name String
A user-friendly name for the layer (e.g., 'dense', 'lstm').
getter/setter pairoverride-getter
parameters List<Tensor>
A list of all trainable tensors (weights and biases) in the layer.
no setteroverride
rate double
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(Tensor input) → void
Initializes the layer's parameters based on the shape of the first input.
inherited
call(Tensor input) Tensor
The public, callable interface for the layer.
inherited
forward(Tensor input) Tensor<Matrix>
The core logic of the layer's transformation.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited