call method

Tensor call(
  1. Tensor input
)

The public, callable interface for the layer.

When a layer instance is called like a function, this method is executed. It acts as a wrapper that automatically handles the build step on the first run before executing the main forward pass logic.

Implementation

Tensor<dynamic> call(Tensor<dynamic> input) {
  if (!_built) {
    build(input);
  }
  return forward(input);
}