activation property
The non-linear activation function to apply to the hidden state.
Tanh is the traditional choice for simple RNNs.
Implementation
ActivationFunction activation;
The non-linear activation function to apply to the hidden state.
Tanh is the traditional choice for simple RNNs.
ActivationFunction activation;