AdamMatrix class
Implements the Adam optimizer for 2D Matrix parameters.
This version is specifically for updating Tensor<Matrix> parameters, such
as the weight matrices in DenseLayer or kernels in Conv2DLayer.
Constructors
Properties
- beta1 → double
-
final
- beta2 → double
-
final
- epsilon → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- learningRate → double
-
The step size for the gradient updates.
finalinherited
-
parameters
→ List<
Tensor> -
The list of model parameters (weights and biases) that this optimizer will update.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
step(
) → void -
Performs a single optimization step (parameter update).
override
-
toString(
) → String -
A string representation of this object.
inherited
-
zeroGrad(
) → void -
Resets the gradients of all parameters to zero.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited