SafetensorsLoader class

Constructors

SafetensorsLoader(String filePath)

Properties

bufferOffset int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
getter/setter pair
rawBytes Uint8List
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAvailableTensors() List<String>
loadIntoTensors(Map<String, GPUTensor> modelTensors) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited