Tensor<T> class

Constructors

Tensor(dynamic initialValue, {Node? creator})

Properties

creator Node?
getter/setter pair
data Float32List
getter/setter pair
dataPtr Pointer<Float>
getter/setter pair
grad Float32List
getter/setter pair
gradPtr Pointer<Float>
getter/setter pair
gradValue → T
no setter
hasData bool
no setter
hashCode int
The hash code for this object.
no setterinherited
id String
getter/setter pair
isFreed bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shape List<int>
getter/setter pair
value → T
no setter

Methods

backward() → void
free() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printGraph() → void
toString() String
A string representation of this object.
inherited
zeroGrad() → void

Operators

operator ==(Object other) bool
The equality operator.
inherited