Mish class
The Mish activation function.
Mish is a modern, self-gated, and smooth non-monotonic activation function
that has achieved state-of-the-art results on a number of computer vision
and NLP benchmarks, often outperforming ReLU and Swish.
The function is defined as $f(x) = x \cdot \tanh(\text{softplus}(x))$.
Example
Layer hiddenLayer = DenseLayer(128, activation: Mish());
- Implemented types
Constructors
- Mish()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
Tensor input) → Tensor< Vector> -
Applies the Mish function element-wise to the input tensor.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited