Softmax class
An activation function that applies Softmax to a Vector.
Softmax converts a vector of real numbers (logits) into a probability distribution where all elements sum to 1. It is the standard activation for the output layer in multi-class classification problems.
This version is designed to work on a single 1D Vector input.
- Implemented types
Constructors
- Softmax()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
Tensor input) → Tensor< Vector> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited