SGDGPU class
- Inheritance
-
- Object
- OptimizerGPU
- SGDGPU
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- learningRate ↔ double
-
getter/setter pair
-
parameters
↔ List<
GPUTensor> -
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
step(
CommandBuffer tape) → void -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
zeroGrad(
CommandBuffer tape) → void -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited