GPUNode class
Constructors
Properties
- backwardFn ↔ void Function(CommandBuffer)
-
getter/setter pair
- cost ↔ int
-
getter/setter pair
-
extraParams
↔ Map<
String, dynamic> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
inputs
↔ List<
GPUTensor> -
getter/setter pair
- opName ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited