GPUTensor<T> class
Constructors
Properties
- creator ↔ GPUNode?
-
getter/setter pair
-
data
↔ List<
double> -
getter/setter pair
-
grad
↔ List<
double> -
getter/setter pair
- gradValue → T
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
shape
↔ List<
int> -
getter/setter pair
- value → T
-
no setter
Methods
-
backward(
CommandBuffer backwardTape, {bool fillOnes = true}) → void -
free(
) → void -
getAllTensorsInGraph(
GPUTensor root) → List< GPUTensor> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
printGraph(
) → void -
pushData(
List< double> values) → void -
toCpu(
) → void -
toString(
) → String -
A string representation of this object.
inherited
-
zeroGrad(
CommandBuffer tape) → void -
zeroGraphGrads(
CommandBuffer tape) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited